'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

require('edge-core-js/lib/client-side.js');
var URL = _interopDefault(require('url-parse'));
var yaob = require('yaob');

const version = "0.6.12";

var styleString = 'border: 0px none transparent; overflow: hidden; margin: 0px; padding: 0px; position: fixed; left: 0px; top: 0px; width: 100%; height: 100%; z-index: 9999;background: transparent;';
var hiddenString = 'display: none';
var visibleString = 'display: block';
/**
 * Creates an iframe under the main window.
 */

function makeFrame(path) {
  if (document == null) {
    throw new Error('This code can only run in a web browser');
  }

  var frame = document.createElement('iframe');
  frame.setAttribute('src', path);
  frame.setAttribute('frameborder', '0');
  frame.setAttribute('allowtransparency', 'true');
  frame.setAttribute('style', styleString + hiddenString); // Add the frame to the document:

  if (!document.body) {
    throw new Error('No <body> element - please call makeEdgeUiContext once the page has loaded');
  }

  document.body.appendChild(frame);
  return frame;
}
function hideFrame(frame) {
  frame.setAttribute('style', styleString + hiddenString);
}
function showFrame(frame) {
  frame.setAttribute('style', styleString + visibleString);
}

/**
 * Sets up the iframe, attaches to it, and returns a context API.
 */
function makeEdgeUiContext(opts) {
  var _opts$assetsPath = opts.assetsPath,
      assetsPath = _opts$assetsPath === void 0 ? "https://developer.airbitz.co/iframe/v" + version + "/" : _opts$assetsPath;
  var frameUrl = new URL(assetsPath);
  var origin = frameUrl.origin;
  var frame = makeFrame(frameUrl.href);
  var bridge = new yaob.Bridge({
    sendMessage: function sendMessage(message) {
      frame.contentWindow.postMessage(message, origin);
    }
  });
  window.addEventListener('message', function (event) {
    if (event.origin !== origin) return; // console.log('client got', event.data)

    bridge.handleMessage(event.data);
  }, false);
  return bridge.getRoot().then(function (root) {
    return root.makeContext(opts);
  }).then(function (context) {
    context.watch('windowVisible', function (visible) {
      return visible ? showFrame(frame) : hideFrame(frame);
    });
    return context;
  });
}

exports.makeEdgeUiContext = makeEdgeUiContext;
//# sourceMappingURL=edge-login-ui-web.cjs.js.map
